@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ev-file-helpers.h 2197 2007-01-08 12:25:31Z nshmyrev $
+ *  $Id: ev-file-helpers.h 2291 2007-02-03 19:02:28Z carlosgc $
  */
 
 #ifndef EPHY_FILE_HELPERS_H
@@ -25,6 +25,12 @@
 
 G_BEGIN_DECLS
 
+typedef enum {
+	EV_COMPRESSION_NONE,
+	EV_COMPRESSION_BZIP2,
+	EV_COMPRESSION_GZIP
+} EvCompressionType;
+
 const gchar *ev_dot_dir               (void);
 
 const gchar *ev_tmp_dir               (void);
@@ -33,11 +39,15 @@ void         ev_file_helpers_init     (void);
 
 void         ev_file_helpers_shutdown (void);
 
-gchar*       ev_tmp_filename          (const char *prefix);
+gchar       *ev_tmp_filename          (const char        *prefix);
+
+gboolean     ev_xfer_uri_simple       (const char        *from,
+				       const char        *to,
+				       GError           **error);
+gchar       *ev_file_uncompress       (const gchar       *uri,
+				       EvCompressionType  type,
+				       GError           **error);
 
-gboolean     ev_xfer_uri_simple       (const char *from,
-				       const char *to,
-				       GError     **error);
 
 G_END_DECLS
 
