@@ -21,8 +21,6 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
-
 #include "ev-stock-icons.h"
 
 #include <gtk/gtkiconfactory.h>
@@ -34,14 +32,17 @@ typedef struct {
 	char *icon;
 } EvStockIcon;
 
-/* Evince stock icons from gnome-icon-theme */
+/* Evince stock icons */
 static const EvStockIcon stock_icons [] = {
-	{ EV_STOCK_ZOOM_PAGE,        "stock_zoom-page" },
-	{ EV_STOCK_ZOOM_WIDTH,       "stock_zoom-page-width" },
-	{ EV_STOCK_LEAVE_FULLSCREEN, "stock_leave-fullscreen" }
+	{ EV_STOCK_ZOOM_PAGE,        "zoom-fit-page" },
+	{ EV_STOCK_ZOOM_WIDTH,       "zoom-fit-width" },
+	{ EV_STOCK_LEAVE_FULLSCREEN, "view-restore" },
+	{ EV_STOCK_VIEW_DUAL,        "view-page-facing" },
+	{ EV_STOCK_VIEW_CONTINUOUS,  "view-page-continuous" },
+	{ EV_STOCK_ROTATE_LEFT,      "object-rotate-left"},
+	{ EV_STOCK_ROTATE_RIGHT,     "object-rotate-right"},
 };
 
-
 void
 ev_stock_icons_init (void)
 {
